<?php
namespace Opencart\Admin\Controller\Design;
/**
 * Class Faq
 *
 * @package Opencart\Admin\Controller\Design
 */
class Faq extends \Opencart\System\Engine\Controller {
	/**
	 * @return void
	 */
	 

	/**
	 * @return void
	 */
	public function list(): void {
		$this->load->language('design/faq');

		$this->response->setOutput($this->getList());
	}

	/**
	 * @return string
	 */
	protected function getList(): string {
		if (isset($this->request->get['sort'])) {
			$sort = (string)$this->request->get['sort'];
		} else {
			$sort = 'question';
		}

		if (isset($this->request->get['order'])) {
			$order = (string)$this->request->get['order'];
		} else {
			$order = 'ASC';
		}

		if (isset($this->request->get['page'])) {
			$page = (int)$this->request->get['page'];
		} else {
			$page = 1;
		}

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['action'] = $this->url->link('design/faq.list', 'user_token=' . $this->session->data['user_token'] . $url);

		$data['faqs'] = [];

		$filter_data = [
			'sort'  => $sort,
			'order' => $order,
			'start' => ($page - 1) * $this->config->get('config_pagination_admin'),
			'limit' => $this->config->get('config_pagination_admin')
		];

		$this->load->model('design/faq');

		$faq_total = $this->model_design_faq->getTotalFaqs();

		$results = $this->model_design_faq->getFaqs($filter_data);

		foreach ($results as $result) {
			$data['faqs'][] = [
				'faq_id' => $result['faq_id'],
				'question'      => $result['question'],
				'status'    => $result['status'],
				'edit'      => $this->url->link('design/faq.form', 'user_token=' . $this->session->data['user_token'] . '&faq_id=' . $result['faq_id'] . $url)
			];
		}

		$url = '';

		if ($order == 'ASC') {
			$url .= '&order=DESC';
		} else {
			$url .= '&order=ASC';
		}

		$data['sort_name'] = $this->url->link('design/faq.list', 'user_token=' . $this->session->data['user_token'] . '&sort=name' . $url);

		$url = '';

		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		$data['pagination'] = $this->load->controller('common/pagination', [
			'total' => $faq_total,
			'page'  => $page,
			'limit' => $this->config->get('config_pagination_admin'),
			'url'   => $this->url->link('design/faq.list', 'user_token=' . $this->session->data['user_token'] . $url . '&page={page}')
		]);

		$data['results'] = sprintf($this->language->get('text_pagination'), ($faq_total) ? (($page - 1) * $this->config->get('config_pagination_admin')) + 1 : 0, ((($page - 1) * $this->config->get('config_pagination_admin')) > ($faq_total - $this->config->get('config_pagination_admin'))) ? $faq_total : ((($page - 1) * $this->config->get('config_pagination_admin')) + $this->config->get('config_pagination_admin')), $faq_total, ceil($faq_total / $this->config->get('config_pagination_admin')));

		$data['sort'] = $sort;
		$data['order'] = $order;

		return $this->load->view('design/faq_list', $data);
	}

	/**
	 * @return void
	 */
	public function index(): void {
		$this->load->language('design/faq');

		$this->document->setTitle($this->language->get('heading_title'));

		$data['text_form'] = !isset($this->request->get['faq_id']) ? $this->language->get('text_add') : $this->language->get('text_edit');

		$url = '';
		$faq_id=0;
		if (isset($this->request->get['faq_id'])) {
			 $faq_id=$this->request->get['faq_id']; 
		}
		$data['faq_id']=$faq_id;
		if (isset($this->request->get['sort'])) {
			$url .= '&sort=' . $this->request->get['sort'];
		}

		if (isset($this->request->get['order'])) {
			$url .= '&order=' . $this->request->get['order'];
		}

		if (isset($this->request->get['page'])) {
			$url .= '&page=' . $this->request->get['page'];
		}

		$data['breadcrumbs'] = [];

		$data['breadcrumbs'][] = [
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'])
		];
		 
		if($faq_id == 7){
			$data['breadcrumbs'][] = [
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('design/faq', 'user_token=' . $this->session->data['user_token'] . $url)
			];
	    }else{
			$data['breadcrumbs'][] = [
				'text' => $this->language->get('heading_gallery'),
				'href' => $this->url->link('design/faq', 'user_token=' . $this->session->data['user_token'] . $url)
			];
		}

		$data['save'] = $this->url->link('design/faq.save', 'user_token=' . $this->session->data['user_token']);
		$data['back'] = $this->url->link('design/faq', 'user_token=' . $this->session->data['user_token'] . $url);

		 

		 

		$this->load->model('localisation/language');

		$data['languages'] = $this->model_localisation_language->getLanguages();

		$this->load->model('design/faq');

		$faqs = $this->model_design_faq->getFaqs();
 
		$data['faqs'] = [];
        
        foreach ($data['languages'] as $language_ids) { 
		foreach ($faqs as $language_id => $value) { 
			 
				 
				$data['faqs'][$language_ids['language_id']][] = [
					'question'      => $value['question'],
					'answer'       => $value['answer'], 
					'sort_order' => $value['sort_order']
				];
			 
		}
        }
  
		 

		$data['user_token'] = $this->session->data['user_token'];

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('design/faq_form', $data));
	}

	/**
	 * @return void
	 */
	public function save(): void {
		$this->load->language('design/faq'); 
		 
			$this->load->model('design/faq');

			if (!$this->request->post['faq_id']) {
				$this->model_design_faq->addFaq($this->request->post);
			} else {
				$this->model_design_faq->editFaq($this->request->post['faq_id'], $this->request->post);
			}

			$json['success'] = $this->language->get('text_success');
		 

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
	}

	/**
	 * @return void
	 */
	public function delete(): void {
		$this->load->language('design/faq');

		$json = [];

		if (isset($this->request->post['selected'])) {
			$selected = $this->request->post['selected'];
		} else {
			$selected = [];
		}

		if (!$this->user->hasPermission('modify', 'design/faq')) {
			$json['error'] = $this->language->get('error_permission');
		}

		if (!$json) {
			$this->load->model('design/faq');

			foreach ($selected as $faq_id) {
				$this->model_design_faq->deleteFaq($faq_id);
			}

			$json['success'] = $this->language->get('text_success');
		}

		$this->response->addHeader('Content-Type: application/json');
		$this->response->setOutput(json_encode($json));
	}
}
